@@ -1,5 +1,6 @@
 package testcover;
 use FindBin;
+use TAP::Harness;
 use File::Glob qw(bsd_glob);
 use Devel::Cover::DB;
 
@@ -9,14 +10,15 @@ sub run {
     my $path     = test_path($name);
     my $cover_db = cover_db_path($name);
 
-    my $prove_cmd = `which prove`;
-    chomp($prove_cmd);
-
     my $cover_cmd = `which cover`;
     chomp($cover_cmd);
 
-    local $ENV{HARNESS_PERL_SWITCHES} = "'-MDevel::Cover=-db,$cover_db'";
-    run_cmd( $prove_cmd, bsd_glob("$path/*.t") );
+    {
+        local $ENV{HARNESS_PERL_SWITCHES} = "'-MDevel::Cover=-db,$cover_db'";
+        my $harness = TAP::Harness->new( { verbosity => -3, lib => [$path] } );
+        $harness->runtests( bsd_glob("$path/*.t") );
+    }
+
     run_cmd( $cover_cmd, $cover_db );
 
     my $db = Devel::Cover::DB->new( db => $cover_db );
@@ -28,7 +30,7 @@ sub run_cmd {
     my @parts = @_;
     my $str = sprintf( "'%s'", join "','", @parts );
     {
-        local *STDOUT;
+        local *STDOUT = STDOUT;
         open( STDOUT, '>', '/dev/null' );
         system(@parts) == 0 or die "system($str) failed: $?";
     }
